@@ -1,6 +1,7 @@
 """REST client handling, including RestApiStream base class."""
 
 from pathlib import Path
+from typing import Any
 
 from singer_sdk.streams import RESTStream
 
@@ -11,6 +12,11 @@ class RestApiStream(RESTStream):
     """rest-api stream class."""
 
     @property
-    def url_base(self) -> str:
-        """Return the API URL root, configurable via tap settings."""
+    def url_base(self) -> Any:
+        """Return the API URL root, configurable via tap settings.
+
+        Returns:
+            The base url for the api call.
+
+        """
         return self.config["api_url"]
